pub enum Purpose {
ProgressUpdate,
HomeworkCoaching,
ProgramCompletionSummary,
ReEnrollmentPrompt,
}Expand description
Follow-up purpose staff review before progress, homework, completion, or re-enrollment copy is drafted.
Variants
ProgressUpdate
Staff can see the progress update training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
HomeworkCoaching
Staff can see the homework coaching training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
ProgramCompletionSummary
Staff can see the program completion summary training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
ReEnrollmentPrompt
Staff can see the re-enrollment prompt training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.